device_calendar_plus library

Classes

Attendee
A participant in a calendar event (read-only).
Calendar
Represents a user's calendar
CalendarSource
Represents a calendar source/account that can own calendars.
CountEnd
Recurrence ends after count occurrences.
CreateCalendarOptionsAndroid
Android-specific options for creating a calendar.
CreateCalendarOptionsIos
iOS-specific options for creating a calendar.
CreateCalendarPlatformOptions
Base class for platform-specific calendar creation options.
DailyRecurrence
Event repeats every N days.
DeviceCalendar
Main API for accessing device calendar functionality.
Event
Represents a calendar event.
InstanceIdParser
Utility for parsing instance IDs.
MonthlyByDate
Monthly recurrence on specific days of the month (BYMONTHDAY).
MonthlyByWeekday
Monthly recurrence on specific weekdays (BYDAY).
MonthlyRecurrence
Event repeats every N months.
ParsedInstanceId
Represents the parsed components of an instance ID.
Patch<T>
A partial-update instruction for an optional, clearable field.
PatchClear<T>
A Patch that clears the field.
PatchSet<T>
A Patch that sets the field to value.
PlatformExceptionCodes
Platform exception codes used for communication between native and Dart.
RecurrenceDay
A day of the week with an optional position for recurring events.
RecurrenceEnd
End condition for a recurrence rule.
RecurrenceRule
Recurrence rule for calendar events (RFC 5545 RRULE subset).
UntilEnd
Recurrence ends on or before until (inclusive / closed interval).
WeeklyRecurrence
Event repeats every N weeks, optionally on specific days.
YearlyByDate
Yearly recurrence on specific months and days of month (BYMONTH + BYMONTHDAY).
YearlyByWeekday
Yearly recurrence on specific weekdays within months (BYMONTH + BYDAY).
YearlyRecurrence
Event repeats every N years.

Enums

AttendeeRole
Role of an attendee in a calendar event.
AttendeeStatus
RSVP status of an attendee.
CalendarPermissionStatus
Represents the current status of calendar permissions.
CalendarSourceType
Type of a calendar source/account.
DayOfWeek
Days of the week for recurrence rules.
DeviceCalendarError
Error codes for device calendar operations.
EventAvailability
Availability status of a calendar event.
EventSpan
Which occurrences of a recurring event an operation applies to.
EventStatus
Status of a calendar event.

Exceptions / Errors

DeviceCalendarException
Exception thrown by device calendar operations.