CreateCalendarOptionsAndroid class

Android-specific options for creating a calendar.

Use this class to specify the account name for the calendar on Android. The calendar will be created under the local account type with the specified account name.

Example:

await plugin.createCalendar(
  name: 'My Calendar',
  platformOptions: CreateCalendarOptionsAndroid(accountName: 'MyApp'),
);
Inheritance

Constructors

CreateCalendarOptionsAndroid({required String accountName, String? accountType})
Creates Android-specific calendar creation options.
const

Properties

accountName String
The account name for the calendar.
final
accountType String?
The account type for the calendar (e.g. "com.google", "LOCAL").
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited