UntilEnd class

Recurrence ends on or before until (inclusive / closed interval).

This differs from Event.endDate which uses an open interval. The until value should be in UTC.

Inheritance

Constructors

UntilEnd(DateTime until)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
until DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override