EventAvailability enum
Availability status of a calendar event.
Values
- busy → const EventAvailability
-
Availability is busy (default for most events).
Available on: Android, iOS
- free → const EventAvailability
-
Availability is free (time is available despite event).
Available on: Android, iOS
- tentative → const EventAvailability
-
Availability is tentative (event is not confirmed).
Available on: Android, iOS
-
Availability is unavailable (out of office, etc.).
Available on: iOS only
- notSupported → const EventAvailability
-
Availability status is not supported or unknown.
Available on: iOS only (when calendar doesn't support availability)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromName(
String name) → EventAvailability - Safely parses a string to an EventAvailability enum. Returns notSupported if the value doesn't match any known case.
Constants
-
values
→ const List<
EventAvailability> - A constant List of the values in this enum, in order of their declaration.