YearlyRecurrence class sealed
Event repeats every N years.
YearlyRecurrence() // same date as event start
YearlyRecurrence(months: [12], daysOfMonth: [25]) // Christmas
YearlyRecurrence(months: [6, 12], daysOfMonth: [15]) // 15th of June and December
YearlyRecurrence.byWeekday( // last Monday of May
months: [5],
daysOfWeek: [RecurrenceDay(DayOfWeek.monday, position: -1)],
)
- Inheritance
-
- Object
- RecurrenceRule
- YearlyRecurrence
- Implementers
Constructors
-
YearlyRecurrence({List<
int> ? months, List<int> ? daysOfMonth, List<int> ? setPositions, int interval, RecurrenceEnd? end, String? rawRrule}) -
Creates a yearly recurrence on specific months and days of month (BYMONTH + BYMONTHDAY).
factory
-
YearlyRecurrence.byWeekday({List<
int> ? months, required List<RecurrenceDay> daysOfWeek, List<int> ? setPositions, int interval, RecurrenceEnd? end, String? rawRrule}) -
Creates a yearly recurrence on specific weekdays within months (BYMONTH + BYDAY).
factory
Properties
- end → RecurrenceEnd?
-
Optional end condition (count or until date). Null means recurs forever.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval → int
-
Interval between recurrences. Defaults to 1.
finalinherited
- rruleString → String
-
The raw RRULE string — use it for RRULE properties beyond the typed model.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setPositions
→ List<
int> ? -
Filters the result set to specific positions (BYSETPOS).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toRruleString(
) → String -
Serializes this rule to an RRULE string (without the "RRULE:" prefix).
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited